@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Speech recognition tools for using Rev.ai"""
+"""Speech recognition tools for using Rev AI"""
 
 import json
 from .models import Account, CaptionType, Job, Transcript
@@ -13,7 +13,7 @@ except ImportError:
 
 
 class RevAiAPIClient(BaseClient):
-    """Client which implements Rev.ai API
+    """Client which implements Rev AI API
 
     Note that HTTPErrors can be thrown by methods of the API client. The HTTP
     response payload attached to these error is a problem details. The problem
@@ -23,7 +23,13 @@ class RevAiAPIClient(BaseClient):
     Problem details are defined at https://tools.ietf.org/html/rfc7807.
     """
 
-    # Rev.ai transcript format
+    # Default version of Rev AI
+    version = 'v1'
+
+    # Default base url for Rev AI
+    base_url = 'https://api.rev.ai/speechtotext/{}/'.format(version)
+
+    # Rev AI transcript format
     rev_json_content_type = 'application/vnd.rev.transcript.v1.0+json'
 
     def __init__(self, access_token):
@@ -31,7 +37,7 @@ class RevAiAPIClient(BaseClient):
 
         :param access_token: access token which authorizes all requests and links them to your
                              account. Generated on the settings page of your account dashboard
-                             on Rev.ai.
+                             on Rev AI.
         """
 
         BaseClient.__init__(self, access_token)
@@ -54,7 +60,8 @@ class RevAiAPIClient(BaseClient):
             verbatim=None,
             rush=None,
             test_mode=None,
-            segments_to_transcribe=None):
+            segments_to_transcribe=None,
+            speaker_names=None):
         """Submit media given a URL for transcription.
         The audio data is downloaded from the URL.
 
@@ -62,9 +69,9 @@ class RevAiAPIClient(BaseClient):
         :param metadata: info to associate with the transcription job
         :param callback_url: callback url to invoke on job completion as
                              a webhook
-        :param skip_diarization: should rev.ai skip diaization when
+        :param skip_diarization: should Rev AI skip diaization when
                                  transcribing this file
-        :param skip_punctuation: should rev.ai skip punctuation when
+        :param skip_punctuation: should Rev AI skip punctuation when
                                  transcribing this file
         :param speaker_channels_count: the number of speaker channels in the
             audio. If provided the given audio will have each channel
@@ -93,6 +100,8 @@ class RevAiAPIClient(BaseClient):
             Whether human transcription job is mocked and no transcription actually happens.
         :param segments_to_transcribe: Only available with "human" transcriber.
             Sections of transcript needed to be transcribed.
+        :param speaker_names: Only available with "human" transcriber.
+            Human readable names of speakers in the file.
         :returns: raw response data
         :raises: HTTPError
         """
@@ -105,7 +114,7 @@ class RevAiAPIClient(BaseClient):
                                                    remove_disfluencies, delete_after_seconds,
                                                    language, custom_vocabulary_id, transcriber,
                                                    verbatim, rush, test_mode,
-                                                   segments_to_transcribe)
+                                                   segments_to_transcribe, speaker_names)
 
         response = self._make_http_request(
             "POST",
@@ -133,7 +142,8 @@ class RevAiAPIClient(BaseClient):
             verbatim=None,
             rush=None,
             test_mode=None,
-            segments_to_transcribe=None):
+            segments_to_transcribe=None,
+            speaker_names=None):
         """Submit a local file for transcription.
         Note that the content type is inferred if not provided.
 
@@ -141,9 +151,9 @@ class RevAiAPIClient(BaseClient):
         :param metadata: info to associate with the transcription job
         :param callback_url: callback url to invoke on job completion as a
                              webhook
-        :param skip_diarization: should rev.ai skip diaization when
+        :param skip_diarization: should Rev AI skip diaization when
                                  transcribing this file
-        :param skip_punctuation: should rev.ai skip punctuation when
+        :param skip_punctuation: should Rev AI skip punctuation when
                                  transcribing this file
         :param speaker_channels_count: the number of speaker channels in the
             audio. If provided the given audio will have each channel
@@ -172,6 +182,8 @@ class RevAiAPIClient(BaseClient):
             Whether human transcription job is mocked and no transcription actually happens.
         :param segments_to_transcribe: Only available with "human" transcriber.
             Sections of transcript needed to be transcribed.
+        :param speaker_names: Only available with "human" transcriber.
+            Human readable names of speakers in the file.
         :returns: raw response data
         :raises: HTTPError
         """
@@ -184,7 +196,7 @@ class RevAiAPIClient(BaseClient):
                                                    remove_disfluencies, delete_after_seconds,
                                                    language, custom_vocabulary_id, transcriber,
                                                    verbatim, rush, test_mode,
-                                                   segments_to_transcribe)
+                                                   segments_to_transcribe, speaker_names)
 
         with open(filename, 'rb') as f:
             files = {
@@ -205,7 +217,7 @@ class RevAiAPIClient(BaseClient):
         The server will respond with the status and creation date.
 
         :param id_: id of the job to be requested
-        :returns: raw response data
+        :returns: Job object if available
         :raises: HTTPError
         """
         if not id_:
@@ -430,7 +442,8 @@ class RevAiAPIClient(BaseClient):
             verbatim=None,
             rush=None,
             test_mode=None,
-            segments_to_transcribe=None):
+            segments_to_transcribe=None,
+            speaker_names=None):
         payload = {}
         if media_url:
             payload['media_url'] = media_url
@@ -467,6 +480,9 @@ class RevAiAPIClient(BaseClient):
             payload['test_mode'] = test_mode
         if segments_to_transcribe:
             payload['segments_to_transcribe'] = segments_to_transcribe
+        if speaker_names:
+            payload['speaker_names'] =\
+                utils._process_speaker_names(speaker_names)
         return payload
 
     def _create_captions_query(self, speaker_channel):
